@@ -30,6 +30,11 @@ $wgRenameuserMessages['en'] = array(
 	'renameuserlog'         => 'Renamed the user "[[User:$1|$1]]" (which had $3 edits) to "[[User:$2|$2]]"',
 	'renameuser-move-log'   => 'Automatically moved page while renaming the user "[[User:$1|$1]]" to "[[User:$2|$2]]"',
 );
+$wgRenameuserMessages['af'] = array(
+	'renameusererrordoesnotexist' => 'Die gebruiker "<nowiki>$1</nowiki>" bestaan nie',
+	'renameusererrorexists'       => 'Die gebruiker "<nowiki>$1</nowiki>" bestaan reeds',
+	'renameusererrorinvalid'      => '"<nowiki>$1</nowiki>" is \'n ongeldige gebruikernaam',
+);
 $wgRenameuserMessages['ar'] = array(
 	'renameuser' => 'أعد تسمية مستخدم',
 	'renameuserold' => 'اسم المستخدم الحالي:',
@@ -46,8 +51,8 @@ $wgRenameuserMessages['ar'] = array(
 	'renameuser-page-unmoved' => 'لم يتمكن من نقل الصفحة $1 إلى $2.',
 	'renameuserlogpage' => 'سجل تغيير أسماء المستخدمين',
 	'renameuserlogpagetext' => 'هذا سجل بالتغييرات في أسماء المستخدمين',
-	'renameuserlog' => 'أعيد تسمية المستخدم "[[مستخدم:$1|$1]]" (والذي كان لديه $3 مساهمة) إلى "[[مستخدم:$2|$2]]"',
-	'renameuser-move-log' => 'تم نقل الصفحة تلقائيا خلال إعادة تسمية المستخدم من "[[مستخدم:$1|$1]]" إلى "[[مستخدم:$2|$2]]"',
+	'renameuserlog' => 'أعيد تسمية المستخدم "[[User:$1|$1]]" (والذي كان لديه $3 مساهمة) إلى "[[User:$2|$2]]"',
+	'renameuser-move-log' => 'تم نقل الصفحة تلقائيا خلال إعادة تسمية المستخدم من "[[User:$1|$1]]" إلى "[[User:$2|$2]]"',
 );
 $wgRenameuserMessages['br'] = array(
 	'renameuser'       => 'Adenvel an implijer',
@@ -148,7 +153,7 @@ $wgRenameuserMessages['fi'] = array(
 	'renameuserlogpage'     => 'Tunnusten vaihdot',
 	'renameuserlogpagetext' => 'Tämä on loki käyttäjätunnuksien vaihdoista.',
 	'renameuserlog'         => 'Käyttäjän ”[[User:$1|$1]]” (tehnyt $3 muokkausta) tunnus on nyt ”[[User:$2|$2]]”',
-	'renameuser-move-log'   => 'Siiretty automaattisesti tunnukselta ”[[User:$1|$1]]” tunnukselle ”[[User:$2|$2]]”',
+	'renameuser-move-log'   => 'Siirretty automaattisesti tunnukselta ”[[User:$1|$1]]” tunnukselle ”[[User:$2|$2]]”',
 );
 $wgRenameuserMessages['fr'] = array(
 	'renameuser'       => 'Renommer l’utilisateur',
@@ -247,7 +252,7 @@ $wgRenameuserMessages['id'] = array(
 
 	'renameuserlogpage'     => 'Log penggantian nama pengguna',
 	'renameuserlogpagetext' => 'Di bawah ini adalah log penggantian nama pengguna',
-	'renameuserlog'         => 'Mengganti nama pengguna "[[User:$1|$1]]" (yang telah memiliki $3 suntingan) menjadi "[[User:$2|$2]]"',
+	'renameuserlog'         => 'mengganti nama pengguna "[[User:$1|$1]]" (yang telah memiliki $3 suntingan) menjadi "[[User:$2|$2]]"',
 	'renameuser-move-log'   => 'Secara otomatis memindahkan halaman sewaktu mengganti nama pengguna "[[User:$1|$1]]" menjadi "[[User:$2|$2]]"',
 );
 $wgRenameuserMessages['it'] = array(
@@ -292,6 +297,29 @@ $wgRenameuserMessages['ja'] = array(
 	'renameuser-move-log' => '名前の変更と共に "[[User:$1|$1]]" を "[[User:$2|$2]]" へ移動しました。',
 );
 
+$wgRenameuserMessages['ka'] = array(
+	'renameuser'       => 'მომხმარებლის სახელის გამოცვლა',
+	'renameuserold'    => 'ამჟამინდელი მომხმარებლის სახელი:',
+	'renameusernew'    => 'ახალი მომხმარებლის სახელი:',
+	'renameusermove'   => 'მომხმარებლისა და განხილვის გვერდების (და მათი დაქვემდებარებული გვერდების) გადატანა ახალ დასახელებაზე',
+	'renameusersubmit' => 'გაგზავნა',
+
+	'renameusererrordoesnotexist' => 'მომხმარებელი "<nowiki>$1</nowiki>" არ არსებობს',
+	'renameusererrorexists'       => 'მომხმარებელი "<nowiki>$1</nowiki>" უკვე არსებობს',
+	'renameusererrorinvalid'      => 'მომხმარებლის სახელი "<nowiki>$1</nowiki>" არასწორია',
+	'renameusererrortoomany'      => 'მომხმარებელს "<nowiki>$1</nowiki>" გაკეთებული აქვს $2 რედაქცია. სახელის შეცვლამ მომხმარებლისათვის, რომელიც $3-ზე მეტ რედაქციას ითვლის, შესაძლოა ზიანი მიაყენოს საიტის ქმედითობას',
+	'renameusersuccess'           => 'მომხმარებლის სახელი - "<nowiki>$1</nowiki>", შეიცვალა "<nowiki>$2</nowiki>"-ით',
+
+	'renameuser-page-exists'         => 'გვერდი $1 უკვე არსებობს და მისი ავტომატურად შენაცვლება შეუძლებელია.',
+	'renameuser-page-moved'          => 'გვერდი $1 გადატანილია $2-ზე.',
+	'renameuser-page-unmoved'        => 'არ მოხერხდა გვერდის $1 გადატანა $2-ზე.',
+
+	'renameuserlogpage'     => 'მომხმარებლის სახელის გადარქმევის რეგისტრაციის ჟურნალი',
+	'renameuserlogpagetext' => 'ეს არის ჟურნალი, სადაც აღრიცხულია მომხმარებლის სახელთა ცვლილებები',
+	'renameuserlog'         => 'მომხმარებლის "[[{{ns:user}}:$1|$1]]" სახელი (რომელსაც გაკეთებული ჰქონდა $3 რედაქცია) შეიცვალა "[[{{ns:user}}:$2|$2]]-ით"',
+	'renameuser-move-log'   => 'ავტომატურად იქნა გადატანილი გვერდი მომხმარებლის "[[{{ns:user}}:$1|$1]]" სახელის შეცვლისას "[[{{ns:user}}:$2|$2]]-ით"',
+);
+
 $wgRenameuserMessages['kk-kz'] = array(
 	'renameuser'       => 'Қатысушыны қайта атау',
 	'renameuserold'    => 'Ағымдағы қатысушы аты:',
@@ -409,6 +437,25 @@ $wgRenameuserMessages['nl'] = array(
 	'renameuserlogpagetext' => 'Hieronder staan gebruikersnamen die gewijzigd zijn',
 	'renameuserlog'         => 'Gebruiker "[[User:$1|$1]]" (met $3 bewerkingen) is hernoemd naar "[[User:$2|$2]]"',
 );
+$wgRenameuserMessages['no'] = array(
+	'renameuser' => 'Omdøp bruker',
+	'renameuserold' => 'Nåværende navn:',
+	'renameusernew' => 'Nytt brukernavn:',
+	'renameusermove' => 'Flytt bruker- og brukerdiskusjonssider (og deres undersider) til nytt navn',
+	'renameusersubmit' => 'Omdøp',
+	'renameusererrordoesnotexist' => 'Brukeren «<nowiki>$1</nowiki>» finnes ikke',
+	'renameusererrorexists' => 'Brukeren «<nowiki>$1</nowiki>» finnes allerede',
+	'renameusererrorinvalid' => 'Brukernavnet «<nowiki>$1</nowiki>» er ugyldig',
+	'renameusererrortoomany' => 'Brukeren «<nowiki>$1</nowiki>» har $2&nbsp;redigeringer. Å omdøpe brukere med mer enn $3&nbsp;redigeringer kan kunne påvirke sidens ytelse.',
+	'renameusersuccess' => 'Brukeren «<nowiki>$1</nowiki>» har blitt omdøpt til «<nowiki>$2</nowiki>»',
+	'renameuser-page-exists' => 'Siden $1 finnes allerede, og kunne ikke erstattes automatisk.',
+	'renameuser-page-moved' => 'Siden $1 har blitt flyttet til $2.',
+	'renameuser-page-unmoved' => 'Siden $1 kunne ikke flyttes til $2.',
+	'renameuserlogpage' => 'Omdøpingslogg',
+	'renameuserlogpagetext' => 'Dette er en logg over endringer i brukernavn.',
+	'renameuserlog' => 'Omdøpte brukeren «[[User:$1|$1]]» (som hadde $3 redigeringer) til «[[User:$2|$2]]»',
+	'renameuser-move-log' => 'Flyttet side automatisk under omdøping av brukeren «[[User:$1|$1]]» til «[[User:$2|$2]]»',
+);
 $wgRenameuserMessages['oc'] = array(
 	'renameuser' => 'Renomenar l\'utilizaire',
 	'renameuserold' => 'Nom actual de l\'utilizaire :',
@@ -444,6 +491,26 @@ $wgRenameuserMessages['pl'] = array(
 	'renameuserlogpagetext' => 'To jest rejestr zmian nazw użytkowników',
 	'renameuserlog'         => 'Zmieniono nazwę użytkownika "[[User:$1|$1]]" (mającego $3 edycji) na "[[User:$2|$2]]"',
 );
+/* Piedmontese (Bèrto 'd Sèra) */
+$wgRenameuserMessages['pms'] = array(
+	'renameuser' => 'Arbatié n\'utent',
+	'renameuserold' => 'Stranòm corent:',
+	'renameusernew' => 'Stranòm neuv:',
+	'renameusermove' => 'Tramuda ëdcò la pàgina utent e cola dle ciaciarade (con tute soe sotapàgine) a lë stranòm neuv',
+	'renameusersubmit' => 'Falo',
+	'renameusererrordoesnotexist' => 'A-i é pa gnun utent ch\'as ës-ciama "<nowiki>$1</nowiki>"',
+	'renameusererrorexists' => 'N\'utent ch\'as ës-ciama "<nowiki>$1</nowiki>" a-i é già',
+	'renameusererrorinvalid' => 'Lë stranòm "<nowiki>$1</nowiki>" a l\'é nen bon',
+	'renameusererrortoomany' => 'L\'utent "<nowiki>$1</nowiki>" a l\'ha fait $2 modìfiche, ch\'a ten-a present che arbatié n\'utent ch\'a l\'abia pì che $3 modìfiche a podrìa feje un brut efet a le prestassion dël sit.',
+	'renameusersuccess' => 'L\'utent "<nowiki>$1</nowiki>" a l\'é stait arbatià an "<nowiki>$2</nowiki>"',
+	'renameuser-page-exists' => 'La pàgina $1 a-i é già e as peul nen passe-ie dzora n\'aotomàtich.',
+	'renameuser-page-moved' => 'La pàgina $1 a l\'ha fait San Martin a $2.',
+	'renameuser-page-unmoved' => 'La pàgina $1 a l\'é pa podusse tramudé a $2.',
+	'renameuserlogpage' => 'Registr dj\'arbatiagi',
+	'renameuserlogpagetext' => 'Sossì a l\'é un registr dle modìfiche djë stranòm dj\'utent',
+	'renameuserlog' => 'L\'utent "[[User:$1|$1]]" (ch\'a l\'avìa $3 modìfiche) a l\'é stait arbatià an "[[User:$2|$2]]"',
+	'renameuser-move-log' => 'Pàgina utent tramudà n\'aotomàtich damëntrè ch\'as arbatiava "[[User:$1|$1]]" an "[[User:$2|$2]]"',
+);
 $wgRenameuserMessages['pt'] = array(
 	'renameuser'       => 'Renomear utilizador',
 	'renameuserold'    => 'Nome de utilizador actual:',
@@ -505,6 +572,22 @@ $wgRenameuserMessages['sk'] = array(
 	'renameuserlog'         => 'Bol premenovaný používateľ "[[User:$1|$1]]" (mal $3 úpravy) na "[[User:$2|$2]]"',
 	'renameuser-move-log'   => 'Automaticky presunutá stránka počas premenovania používateľa "[[User:$1|$1]]" na "[[User:$2|$2]]"',
 );
+$wgRenameuserMessages['sq'] = array(
+	'renameuser'                  => 'Ndërrim përdoruesi',
+	'renameusererrordoesnotexist' => 'Përdoruesi me emër "<nowiki>$1</nowiki>" nuk ekziston',
+	'renameusererrorexists'       => 'Përdoruesi me emër "<nowiki>$1</nowiki>" ekziston',
+	'renameusererrorinvalid'      => 'Emri "<nowiki>$1</nowiki>" nuk është i lejuar',
+	'renameusererrortoomany'      => 'Përdoruesi "<nowiki>$1</nowiki>" ka dhënë $2 kontribute. Ndryshimi i emrit të një përdoruesi me më shumë se $3 kontribute mund të ndikojë rëndë tek rendimenti i shërbyesave.',
+	'renameuserlog'               => 'i ndërrojë emrin përdoruesit "[[User:$1|$1]]" (me $3 kontribute) tek "[[User:$2|$2]]"',
+	'renameuserlogentry'          => '.',
+	'renameuserlogpage'           => 'Regjistri i emër-ndryshimeve',
+	'renameuserlogpagetext'       => 'Ky është një regjistër i ndryshimeve së emrave të përdoruesve',
+	'renameusermove'              => 'Zhvendos faqet e përdoruesit dhe të diskutimit (dhe nën-faqet e tyre) tek emri i ri',
+	'renameusernew'               => 'Emri i ri',
+	'renameuserold'               => 'Emri i tanishëm',
+	'renameusersubmit'            => 'Ndryshoje',
+	'renameusersuccess'           => 'Përdoruesi "<nowiki>$1</nowiki>" u riemërua në "<nowiki>$2</nowiki>"',
+);
 
 $wgRenameuserMessages['su'] = array(
 	'renameuser' => 'Ganti ngaran pamaké',
@@ -552,51 +635,7 @@ $wgRenameuserMessages['wa'] = array(
 	'renameuserlogpage' => 'Djournå des candjmints d\' no d\' uzeus',
 	'renameuserlogpagetext' => 'Chal pa dzo c\' est ene djivêye des uzeus k\' ont candjî leu no d\' elodjaedje.',
 );
-$wgRenameuserMessages['zh-cn'] = array(
-	'renameuser'       => '用户重命名',
-	'renameuserold'    => '当前用户名：',
-	'renameusernew'    => '新用户名：',
-	'renameusermove'   => '移动用户页及其对话页（包括各子页）到新的名字',
-	'renameusersubmit' => '提交',
-
-	'renameusererrordoesnotexist' => '用户"<nowiki>$1</nowiki>"不存在',
-	'renameusererrorexists'       => '用户"<nowiki>$1</nowiki>"已存在',
-	'renameusererrorinvalid'      => '用户名"<nowiki>$1</nowiki>"不可用',
-	'renameusererrortoomany'      => '用户"<nowiki>$1</nowiki>"贡献了$2次，重命名一个超过$3次的用户会影响站点性能',
-	'renameusersuccess'           => '用户"<nowiki>$1</nowiki>"已经更名为"<nowiki>$2</nowiki>"',
-
-	'renameuser-page-exists'         => '$1这一页己经存在，不能自动覆写。',
-	'renameuser-page-moved'          => '$1这一页已经移动到$2。',
-	'renameuser-page-unmoved'        => '$1这一页不能移动到$2。',
-
-	'renameuserlogpage'     => '用户名变更日志',
-	'renameuserlogpagetext' => '这是用户名更改的日志',
-	'renameuserlog'         => '已重命名用户 "[[User:$1|$1]]" (拥有$3次编辑) 为 "[[User:$2|$2]]"',
-	'renameuser-move-log'   => '当由"[[User:$1|$1]]"重命名作"[[User:$2|$2]]"时已经自动移动用户页',
-);
-$wgRenameuserMessages['zh-tw'] = array(
-	'renameuser'       => '用戶重新命名',
-	'renameuserold'    => '現時用戶名：',
-	'renameusernew'    => '新用戶名：',
-	'renameusermove'   => '移動用戶頁及其對話頁（包括各子頁）到新的名字',
-	'renameusersubmit' => '提交',
-
-	'renameusererrordoesnotexist' => '用戶"<nowiki>$1</nowiki>"不存在',
-	'renameusererrorexists'       => '用戶"<nowiki>$1</nowiki>"已存在',
-	'renameusererrorinvalid'      => '用戶名"<nowiki>$1</nowiki>"不可用',
-	'renameusererrortoomany'      => '用戶"<nowiki>$1</nowiki>"貢獻了$2次，重新命名一個超過$3次的用戶會影響網站效能',
-	'renameusersuccess'           => '用戶"<nowiki>$1</nowiki>"已經更名為"<nowiki>$2</nowiki>"',
-
-	'renameuser-page-exists'         => '$1這一頁己經存在，不能自動覆寫。',
-	'renameuser-page-moved'          => '$1這一頁已經移動到$2。',
-	'renameuser-page-unmoved'        => '$1這一頁不能移動到$2。',
-
-	'renameuserlogpage'     => '用戶名變更日誌',
-	'renameuserlogpagetext' => '這是用戶名更改的日誌',
-	'renameuserlog'         => '已重新命名用戶 "[[User:$1|$1]]" (擁有$3次編輯) 為 "[[User:$2|$2]]"',
-	'renameuser-move-log'   => '當由"[[User:$1|$1]]"重新命名作"[[User:$2|$2]]"時已經自動移動用戶頁',
-);
-$wgRenameuserMessages['zh-yue'] = array(
+$wgRenameuserMessages['yue'] = array(
 	'renameuser'       => '改用戶名',
 	'renameuserold'    => '現時嘅用戶名：',
 	'renameusernew'    => '新嘅用戶名：',
@@ -618,6 +657,54 @@ $wgRenameuserMessages['zh-yue'] = array(
 	'renameuserlog'         => '已經將用戶 "[[User:$1|$1]]" (擁有$3次編輯) 改名做 "[[User:$2|$2]]"',
 	'renameuser-move-log'   => '當由"[[User:$1|$1]]"改名做"[[User:$2|$2]]"嗰陣已經自動搬咗用戶頁',
 );
-$wgRenameuserMessages['zh-hk'] = $wgRenameuserMessages['zh-tw'];
-$wgRenameuserMessages['zh-sg'] = $wgRenameuserMessages['zh-cn'];
-?>
+$wgRenameuserMessages['zh-hans'] = array(
+	'renameuser'       => '用户重命名',
+	'renameuserold'    => '当前用户名：',
+	'renameusernew'    => '新用户名：',
+	'renameusermove'   => '移动用户页及其对话页（包括各子页）到新的名字',
+	'renameusersubmit' => '提交',
+
+	'renameusererrordoesnotexist' => '用户"<nowiki>$1</nowiki>"不存在',
+	'renameusererrorexists'       => '用户"<nowiki>$1</nowiki>"已存在',
+	'renameusererrorinvalid'      => '用户名"<nowiki>$1</nowiki>"不可用',
+	'renameusererrortoomany'      => '用户"<nowiki>$1</nowiki>"贡献了$2次，重命名一个超过$3次的用户会影响站点性能',
+	'renameusersuccess'           => '用户"<nowiki>$1</nowiki>"已经更名为"<nowiki>$2</nowiki>"',
+
+	'renameuser-page-exists'         => '$1这一页己经存在，不能自动覆写。',
+	'renameuser-page-moved'          => '$1这一页已经移动到$2。',
+	'renameuser-page-unmoved'        => '$1这一页不能移动到$2。',
+
+	'renameuserlogpage'     => '用户名变更日志',
+	'renameuserlogpagetext' => '这是用户名更改的日志',
+	'renameuserlog'         => '已重命名用户 "[[User:$1|$1]]" (拥有$3次编辑) 为 "[[User:$2|$2]]"',
+	'renameuser-move-log'   => '当由"[[User:$1|$1]]"重命名作"[[User:$2|$2]]"时已经自动移动用户页',
+);
+$wgRenameuserMessages['zh-hant'] = array(
+	'renameuser'       => '用戶重新命名',
+	'renameuserold'    => '現時用戶名：',
+	'renameusernew'    => '新用戶名：',
+	'renameusermove'   => '移動用戶頁及其對話頁（包括各子頁）到新的名字',
+	'renameusersubmit' => '提交',
+
+	'renameusererrordoesnotexist' => '用戶"<nowiki>$1</nowiki>"不存在',
+	'renameusererrorexists'       => '用戶"<nowiki>$1</nowiki>"已存在',
+	'renameusererrorinvalid'      => '用戶名"<nowiki>$1</nowiki>"不可用',
+	'renameusererrortoomany'      => '用戶"<nowiki>$1</nowiki>"貢獻了$2次，重新命名一個超過$3次的用戶會影響網站效能',
+	'renameusersuccess'           => '用戶"<nowiki>$1</nowiki>"已經更名為"<nowiki>$2</nowiki>"',
+
+	'renameuser-page-exists'         => '$1這一頁己經存在，不能自動覆寫。',
+	'renameuser-page-moved'          => '$1這一頁已經移動到$2。',
+	'renameuser-page-unmoved'        => '$1這一頁不能移動到$2。',
+
+	'renameuserlogpage'     => '用戶名變更日誌',
+	'renameuserlogpagetext' => '這是用戶名更改的日誌',
+	'renameuserlog'         => '已重新命名用戶 "[[User:$1|$1]]" (擁有$3次編輯) 為 "[[User:$2|$2]]"',
+	'renameuser-move-log'   => '當由"[[User:$1|$1]]"重新命名作"[[User:$2|$2]]"時已經自動移動用戶頁',
+);
+$wgRenameuserMessages['zh-cn'] = $wgRenameuserMessages['zh-hans'];
+$wgRenameuserMessages['zh-hk'] = $wgRenameuserMessages['zh-hant'];
+$wgRenameuserMessages['zh-sg'] = $wgRenameuserMessages['zh-hans'];
+$wgRenameuserMessages['zh-tw'] = $wgRenameuserMessages['zh-hant'];
+$wgRenameuserMessages['zh-yue'] = $wgRenameuserMessages['yue'];
+
+
